# @dessia/plot-data

<!-- To add back once the package is published -->
<!-- [![npm (scoped)](https://img.shields.io/npm/v/@dessia/plot-data.svg)](https://www.npmjs.com/package/@dessia/plot-data)
[![npm bundle size (minified)](https://img.shields.io/bundlephobia/min/@dessia/plot-data.svg)](https://www.npmjs.com/package/@dessia/plot-data)
![npm](https://img.shields.io/npm/dt/@dessia/plot-data) -->
![GitHub last commit](https://img.shields.io/github/last-commit/Dessia-tech/plot_data)

## Install

```
npm i @dessia/plot-data
```

## Usage

```
<<<<<<< HEAD
import * as plotdata from '@natsudzn/plot-data';
```

## Develop

```
npm i
npm run-script build
```
=======
import * as plotdata from '@dessia/plot-data';
```

## Changelog

Check the changelog [here](CHANGELOG.md)
>>>>>>> f831483d8d375c8e8a9526e6858d582f01044851
